/*
 *  Power BI Visualizations
 *
 *  Copyright (c) Microsoft Corporation
 *  All rights reserved.
 *  MIT License
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the ""Software""), to deal
 *  in the Software without restriction, including without limitation the rights
 *  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in
 *  all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED *AS IS*, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 *  THE SOFTWARE.
 */

"use strict";

import { Color, color, rgb } from "d3";
import { dataViewObjectsParser } from "powerbi-visuals-utils-dataviewutils";
import { getFillColor } from "powerbi-visuals-utils-dataviewutils/lib/dataViewObjects";
import DataViewObjectsParser = dataViewObjectsParser.DataViewObjectsParser;

export class VisualSettings extends DataViewObjectsParser {
  public animation: AnimationSettings = new AnimationSettings();
  public layout:LayoutSettings=new LayoutSettings();
  public tag:TagSettings=new TagSettings();
}

export class AnimationSettings {
  public stepLength:number=1;//n% * width
  public interval:number=20;//ms
}
export class LayoutSettings{
  public rowsCount:number=1;
  public rowGap:number=2;//n% * height
  public columnGap:number=2;//n% * width
}
export class TagSettings{
  public show:boolean=false;
  public textSize:number=12;
  public fontColor:Color=rgb(0,0,0);
  public transparency:number=0;
  public position:TagPosition=TagPosition.above;
}
export enum TagPosition{
  "above","bottom"
}